@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use base qw/Import::Export/;
 
@@ -25,7 +25,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -44,12 +44,11 @@ Version 0.02
 
 This is the only function of this module. It takes a scalar, array or hash lvalue as the first argument, and a list of one or more values depending on the type of the first argument as the value for the variable. It will set the variable to that value and subsequently make it readonly. Arrays and hashes will be made deeply readonly.
 
-	const my %factory = (
+	const my %factory => (
 		workers => 5,
 		cb => sub { ... }
 	);
 
-
 	$factory{workers}; # 5;
 	$factory{cb}->();
 
